@@ -71,6 +71,28 @@ class FileUtils:
 
         return b_success
 
+    def create_folders(self, s_folder):
+        """
+        Creates all the folder path if any of the subdirs does not exist
+        :param s_folder: Folders and subfolders to be created
+        :return: boolean indicating an error
+        """
+
+        # If the folder already exists, we will not raise an error
+        b_success = self.folder_exists(s_folder)
+        if b_success is True:
+            return True
+
+        # Commented for Compatibility with Python 2.x
+        # b_success: bool = True
+        b_success = True
+        try:
+            os.makedirs(s_folder)
+        except IOError:
+            b_success = False
+
+        return b_success
+
     def delete(self, s_file):
         """
         This method deletes a given file
